@@ -1,5 +1,5 @@
 package CMS::Drupal;
-$CMS::Drupal::VERSION = '0.095';
+$CMS::Drupal::VERSION = '0.90';
 # ABSTRACT: Perl interface to the Drupal CMS
 
 use strict;
@@ -12,12 +12,17 @@ use Type::Params       qw/ compile /;
 
 use DBI;
 use Carp qw/ confess croak /;
+use Data::Dumper;
 
 sub dbh {
   my $self = shift;
   return $self->{'_dbh'} if defined( $self->{'_dbh'} );
 
-  my $args = { @_ };
+  # We want to be able to run with no params if we have them in the env. But
+  # we don't want to use those creds when we are running certain tests
+  my $args = (exists $ENV{'DRUPAL_TEST_CREDS'} and ! exists $ENV{'DRUPAL_TESTING'}) ?
+               { split(',', $ENV{'DRUPAL_TEST_CREDS'}) } :
+               { @_ };
 
   confess "Fatal error! No database name provided! " unless exists $args->{'database'};
   confess "Fatal error! No dbi:driver provided! "    unless exists $args->{'driver'};
@@ -62,7 +67,7 @@ CMS::Drupal - Perl interface to the Drupal CMS
 
 =head1 VERSION
 
-version 0.095
+version 0.90
 
 =head1 SYNOPSIS
 
@@ -70,14 +75,14 @@ version 0.095
 
   my $drupal = CMS::Drupal->new();
 
-  my $database_handle = CMS::Drupal->dbh(
+  my $database_handle = $drupal->dbh(
     'database' => "my_db",
     'driver'   => "mysql",
     'username' => "my_user",
     'password' => "my_password",
     'host'     => "my_host",
     'port'     => "3306",
-    'prefix"   => "myapp_"
+    'prefix'   => "myapp_"
   );
 
 =head1 DESCRIPTION
@@ -203,23 +208,24 @@ B<Quote>
 
 B<End Quote>
 
-=head1 FUNCTIONALITY
-
-As of this writing, all the author needs is a DB handle in order to use other
-CMS::Drupal::* modules. You are welcome to contribute code if you want this
-module to do anything else. For example, many CMS interfaces allow you to put
-the CMS into "maintenance mode," so you can work on the database with the
-site off-line. It would be relatively simple to add methods for tasks such as
-that.
-
 =head1 USAGE
 
 Use the module as shown in the Synopsis above.
 
 =head1 SEE ALSO
 
+=over 4
+
+=item *
+
 L<CMS::Drupal::Types|CMS::Drupal::Types>
 
+=item *
+
+L<CMS::Drupal::Admin|CMS::Drupal::Admin>
+
+=back
+
 =head1 AUTHOR
 
 Nick Tonkin <tonkin@cpan.org>
