@@ -1,5 +1,5 @@
 package CMS::Drupal::Admin::MaintenanceMode;
-$CMS::Drupal::Admin::MaintenanceMode::VERSION = '0.095';
+$CMS::Drupal::Admin::MaintenanceMode::VERSION = '0.90';
 # ABSTRACT: Put your Drupal site into Maintenance Mode, or take it out
 
 use strict;
@@ -84,7 +84,7 @@ CMS::Drupal::Admin::MaintenanceMode - Put your Drupal site into Maintenance Mode
 
 =head1 VERSION
 
-version 0.095
+version 0.90
 
 =head1 SYNOPSIS
 
@@ -116,7 +116,7 @@ user credentials for your database in order to use these tools.
 =head2 maintenance_mode_check
 
 Returns 1 if the site is currently in maintenance mode, otherwise
-returns 0. Take one argument; your active $dbh.
+returns 0. Takes one argument; your active $dbh.
 
 =head2 maintenance_mode_on
 
